@@ -2,7 +2,9 @@
 extern crate lazy_static;
 
 pub use capitalize::capitalize;
+pub use charset::{has_ansi, has_astral, has_han, REG_ANSI, REG_ASTRAL, REG_HAN, strip_ansi, strip_astral};
 pub use concat::{Concat, concat_lines, concat_lines_edged, contingent_lines, join};
+pub use lange::lange;
 pub use str_value::str_value;
 pub use sub::sub;
 
@@ -13,4 +15,6 @@ mod capitalize;
 mod str_value;
 mod sub;
 mod concat;
-mod bracket;
\ No newline at end of file
+mod bracket;
+mod charset;
+mod lange;
\ No newline at end of file
